/*
 * Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8072945 8081854 8141492 8148985 8150188
 * @summary Test the version of HTML generated by the javadoc tool.
 * @author bpatel
 * @library ../lib
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build JavadocTester
 * @run main TestHtmlVersion
 */

public class TestHtmlVersion extends JavadocTester {

    public static void main(String... args) throws Exception {
        TestHtmlVersion tester = new TestHtmlVersion();
        tester.runTests();
    }

    @Test
    void test1() {
        javadoc("-d", "out-1", "-private", "-linksource", "-html5",
                "-sourcepath", testSrc,
                "-use",
                "pkg", "pkg1", "pkg2", "pkg3");
        checkExit(Exit.OK);

        html5Output();
        html5NegatedOutput();
    }

    @Test
    void test2() {
        javadoc("-d", "out-2", "-private", "-linksource", "-html4",
                "-sourcepath", testSrc,
                "-use",
                "pkg", "pkg1", "pkg2", "pkg3");
        checkExit(Exit.OK);

        html4Output();
        html4NegatedOutput();
    }

    @Test
    void test3() {
        javadoc("-d", "out-3", "-private", "-linksource",
                "-sourcepath", testSrc,
                "-use",
                "pkg", "pkg1", "pkg2", "pkg3");
        checkExit(Exit.OK);

        html4Output();
        html4NegatedOutput();
    }

    @Test
    void test4() {
        javadoc("-d", "out-4", "-private", "-linksource", "-html5",
                "-sourcepath", testSrc,
                "-use",
                "pkg3");
        checkExit(Exit.OK);
    }

    void html5Output() {
        // Test for overview-frame page
        checkOutput("overview-frame.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<nav role=\"navigation\" class=\"indexNav\">\n"
                + "<ul>\n"
                + "<li><a href=\"allclasses-frame.html\" target=\"packageFrame\">All&nbsp;Classes</a></li>",
                "<main role=\"main\" class=\"indexContainer\">\n"
                + "<h2 title=\"Packages\">Packages</h2>");

        // Test for allclasses-frame page
        checkOutput("allclasses-frame.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<main role=\"main\" class=\"indexContainer\">\n"
                + "<ul>\n"
                + "<li>");

        // Test for allclasses-noframe page
        checkOutput("allclasses-noframe.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<main role=\"main\" class=\"indexContainer\">\n"
                + "<ul>\n"
                + "<li>");

        // Test for overview-summary page
        checkOutput("overview-summary.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"overviewSummary\">\n"
                + "<caption>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for package-frame page
        checkOutput("pkg/package-frame.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<main role=\"main\">\n"
                + "<h1 class=\"bar\"><a href=\"../pkg/package-summary.html\" target=\"classFrame\">pkg</a></h1>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Interfaces\">Interfaces</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Classes\">Classes</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Enums\">Enums</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Exceptions\">Exceptions</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Errors\">Errors</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Annotation Types\">Annotation Types</h2>");

        // Test for package-summary page
        checkOutput("pkg/package-summary.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"typeSummary\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Package pkg Description\">Package pkg Description</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for package-tree page
        checkOutput("pkg/package-tree.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<li class=\"circle\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Class Hierarchy\">Class Hierarchy</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Interface Hierarchy\">Interface Hierarchy</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Annotation Type Hierarchy\">Annotation Type Hierarchy</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Enum Hierarchy\">Enum Hierarchy</h2>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for package-use page
        checkOutput("pkg1/package-use.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"useSummary\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for constant-values page
        checkOutput("constant-values.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"constantsSummary\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Contents\">Contents</h2>\n",
                "<section role=\"region\">\n"
                + "<h2 title=\"pkg\">pkg.*</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for deprecated-list page
        checkOutput("deprecated-list.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"deprecatedSummary\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for serialized-form page
        checkOutput("serialized-form.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Package\">Package&nbsp;pkg</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for overview-tree page
        checkOutput("overview-tree.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<li class=\"circle\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Class Hierarchy\">Class Hierarchy</h2>\n",
                "<section role=\"region\">\n"
                + "<h2 title=\"Interface Hierarchy\">Interface Hierarchy</h2>\n",
                "<section role=\"region\">\n"
                + "<h2 title=\"Annotation Type Hierarchy\">Annotation Type Hierarchy</h2>\n",
                "<section role=\"region\">\n"
                + "<h2 title=\"Enum Hierarchy\">Enum Hierarchy</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for index-all page
        checkOutput("index-all.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "</header>\n"
                + "<main role=\"main\">",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for src-html page
        checkOutput("src-html/pkg/AnotherClass.html", true,
                "<!DOCTYPE HTML>",
                "<main role=\"main\">\n"
                + "<div class=\"sourceContainer\">");

        // Test for help-doc page
        checkOutput("help-doc.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2>Overview</h2>\n",
                "<section role=\"region\">\n"
                + "<h2>Package</h2>\n",
                "<section role=\"region\">\n"
                + "<h2>Class/Interface</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for a regular class page and members (nested class, field, constructore and method)
        checkOutput("pkg/AnotherClass.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"nested.class.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Nested Class Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"field.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Field Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"field.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Field Detail</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for enum page
        checkOutput("pkg/AnotherClass.ModalExclusionType.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"enum.constant.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Enum Constant Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"enum.constant.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Enum Constant Detail</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for interface page
        checkOutput("pkg2/Interface.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for error page
        checkOutput("pkg/TestError.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for exception page
        checkOutput("pkg/TestException.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for annotation page
        checkOutput("pkg2/TestAnnotationType.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"annotation.type.required.element.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Required Element Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"annotation.type.optional.element.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Optional Element Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"annotation.type.element.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Element Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for class use page
        checkOutput("pkg1/class-use/RegClass.html", true,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<table class=\"useSummary\">",
                "<section role=\"region\"><a id=\"pkg\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Uses of <a href=\"../../pkg1/RegClass.html\" title=\"class in pkg1\">RegClass</a> in <a href=\"../../pkg/package-summary.html\">pkg</a></h3>\n"
                + "<table class=\"useSummary\">",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Test for main index page
        checkOutput("index.html", true,
                "<!DOCTYPE HTML>",
                "<link rel=\"stylesheet\" type=\"text/css\" href=\"stylesheet.css\" title=\"Style\">",
                "<body onload=\"loadFrames()\">\n"
                + "<main role=\"main\">\n"
                + "<div class=\"mainContainer\">\n"
                + "<div class=\"leftContainer\">\n"
                + "<div class=\"leftTop\">\n"
                + "<iframe src=\"overview-frame.html\" name=\"packageListFrame\" title=\"All Packages\"></iframe>\n"
                + "</div>");
    }

    void html5NegatedOutput() {
        // Negated test for overview-frame page
        checkOutput("overview-frame.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<div class=\"indexNav\">\n"
                + "<ul>\n"
                + "<li><a href=\"allclasses-frame.html\" target=\"packageFrame\">All&nbsp;Classes</a></li>",
                "<div class=\"indexContainer\">\n"
                + "<h2 title=\"Packages\">Packages</h2>");

        // Negated test for allclasses-frame page
        checkOutput("allclasses-frame.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<div class=\"indexContainer\">\n"
                + "<ul>\n"
                + "<li>");

        // Negated test for allclasses-noframe page
        checkOutput("allclasses-noframe.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<div class=\"indexContainer\">\n"
                + "<ul>\n"
                + "<li>");

        // Negated test for overview-summary page
        checkOutput("overview-summary.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"overviewSummary\" summary=\"Packages table, listing packages, and an explanation\">\n"
                + "<caption>",
                "</noscript>\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->");

        // Negated test for package-frame page
        checkOutput("pkg/package-frame.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<body>\n"
                + "<h1 class=\"bar\"><a href=\"../pkg/package-summary.html\" target=\"classFrame\">pkg</a></h1>");

        // Negated test for package-summary page
        checkOutput("pkg/package-summary.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"typeSummary\" summary=\"Interface Summary table, listing interfaces, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Class Summary table, listing classes, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Enum Summary table, listing enums, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Exception Summary table, listing exceptions, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Error Summary table, listing errors, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Annotation Types Summary table, listing annotation types, and an explanation\">");

        // Negated test for package-tree page
        checkOutput("pkg/package-tree.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>");

        // Negated test for package-use page
        checkOutput("pkg1/package-use.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"useSummary\" summary=\"Use table, listing packages, and an explanation\">");

        // Negated test for constant-values page
        checkOutput("constant-values.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<table class=\"constantsSummary\" summary=\"Constant Field Values table, listing constant fields, and values\">");

        // Negated test for deprecated-list page
        checkOutput("deprecated-list.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">\n"
                + "<h1 title=\"Deprecated API\" class=\"title\">Deprecated API</h1>\n"
                + "<h2 title=\"Contents\">Contents</h2>",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Classes table, listing deprecated classes, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Enums table, listing deprecated enums, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Exceptions table, listing deprecated exceptions, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Errors table, listing deprecated errors, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Annotation Types table, listing deprecated annotation types, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Fields table, listing deprecated fields, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Methods table, listing deprecated methods, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Constructors table, listing deprecated constructors, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Enum Constants table, listing deprecated enum constants, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Annotation Type Elements table, listing deprecated annotation type elements, and an explanation\">");

        // Negated test for serialized-form page
        checkOutput("serialized-form.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<li class=\"blockList\">\n"
                + "<h2 title=\"Package\">Package&nbsp;pkg</h2>");

        // Negated test for overview-tree page
        checkOutput("overview-tree.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<div class=\"contentContainer\">\n"
                + "<h2 title=\"Class Hierarchy\">Class Hierarchy</h2>",
                "</ul>\n"
                + "<h2 title=\"Interface Hierarchy\">Interface Hierarchy</h2>",
                "</ul>\n"
                + "<h2 title=\"Enum Hierarchy\">Enum Hierarchy</h2>");

        // Negated test for index-all page
        checkOutput("index-all.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"contentContainer\">");

        // Negated test for src-html page
        checkOutput("src-html/pkg/AnotherClass.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<body>\n"
                + "<div class=\"sourceContainer\">");

        // Negated test for help-doc page
        checkOutput("help-doc.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\">\n"
                + "<h2>Overview</h2>",
                "<li class=\"blockList\">\n"
                + "<h2>Package</h2>",
                "<li class=\"blockList\">\n"
                + "<h2>Class/Interface</h2>");

        // Negated test for a regular class page and members (nested class, field, constructore and method)
        checkOutput("pkg/AnotherClass.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- ======== NESTED CLASS SUMMARY ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"nested.class.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Nested Class Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Nested Class Summary table, listing nested classes, and an explanation\">",
                "<!-- =========== FIELD SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"field.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Field Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Field Summary table, listing fields, and an explanation\">",
                "<!-- ======== CONSTRUCTOR SUMMARY ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Constructor Summary table, listing constructors, and an explanation\">",
                "<!-- ========== METHOD SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Method Summary table, listing methods, and an explanation\">",
                "<!-- ============ FIELD DETAIL =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"field.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Field Detail</h3>",
                "<!-- ========= CONSTRUCTOR DETAIL ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>",
                "<!-- ============ METHOD DETAIL ========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>");

        // Negated test for enum page
        checkOutput("pkg/AnotherClass.ModalExclusionType.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- =========== ENUM CONSTANT SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"enum.constant.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Enum Constant Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Enum Constant Summary table, listing enum constants, and an explanation\">",
                "<!-- ========== METHOD SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Method Summary table, listing methods, and an explanation\">",
                "<!-- ============ ENUM CONSTANT DETAIL =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"enum.constant.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Enum Constant Detail</h3>",
                "<!-- ============ METHOD DETAIL ========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>");

        // Negated test for interface page
        checkOutput("pkg2/Interface.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- ========== METHOD SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Method Summary table, listing methods, and an explanation\">",
                "<!-- ============ METHOD DETAIL ========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>");

        // Negated test for error page
        checkOutput("pkg/TestError.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- ======== CONSTRUCTOR SUMMARY ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>",
                "<!-- ========= CONSTRUCTOR DETAIL ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>");

        // Negated test for exception page
        checkOutput("pkg/TestException.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- ======== CONSTRUCTOR SUMMARY ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>",
                "<!-- ========= CONSTRUCTOR DETAIL ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>");

        // Negated test for annotation page
        checkOutput("pkg2/TestAnnotationType.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- =========== ANNOTATION TYPE REQUIRED MEMBER SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"annotation.type.required.element.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Required Element Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Required Element Summary table, listing required elements, and an explanation\">",
                "<!-- =========== ANNOTATION TYPE OPTIONAL MEMBER SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"annotation.type.optional.element.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Optional Element Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Optional Element Summary table, listing optional elements, and an explanation\">",
                "<!-- ============ ANNOTATION TYPE MEMBER DETAIL =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"annotation.type.element.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Element Detail</h3>");

        // Negated test for class use page
        checkOutput("pkg1/class-use/RegClass.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<table class=\"useSummary\" summary=\"Use table, listing packages, and an explanation\">",
                "<li class=\"blockList\"><a name=\"pkg\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Uses of <a href=\"../../pkg1/RegClass.html\" title=\"class in pkg1\">RegClass</a> in <a href=\"../../pkg/package-summary.html\">pkg</a></h3>\n"
                + "<table class=\"useSummary\" summary=\"Use table, listing fields, and an explanation\">");

        // Negated test for main index page
        checkOutput("index.html", false,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<body>\n"
                + "<div class=\"mainContainer\">\n");
    }

    void html4Output() {
        // Test for overview-frame page
        checkOutput("overview-frame.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<div class=\"indexNav\">\n"
                + "<ul>\n"
                + "<li><a href=\"allclasses-frame.html\" target=\"packageFrame\">All&nbsp;Classes</a></li>",
                "<div class=\"indexContainer\">\n"
                + "<h2 title=\"Packages\">Packages</h2>");

        // Test for allclasses-frame page
        checkOutput("allclasses-frame.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<div class=\"indexContainer\">\n"
                + "<ul>\n"
                + "<li>");

        // Test for allclasses-noframe page
        checkOutput("allclasses-noframe.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<div class=\"indexContainer\">\n"
                + "<ul>\n"
                + "<li>");

        // Test for overview-summary page
        checkOutput("overview-summary.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"overviewSummary\" summary=\"Packages table, listing packages, and an explanation\">\n"
                + "<caption>",
                "</noscript>\n"
                + "<div class=\"fixedNav\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->");

        // Test for package-frame page
        checkOutput("pkg/package-frame.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<body>\n"
                + "<h1 class=\"bar\"><a href=\"../pkg/package-summary.html\" target=\"classFrame\">pkg</a></h1>");

        // Test for package-summary page
        checkOutput("pkg/package-summary.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"typeSummary\" summary=\"Interface Summary table, listing interfaces, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Class Summary table, listing classes, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Enum Summary table, listing enums, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Exception Summary table, listing exceptions, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Error Summary table, listing errors, and an explanation\">",
                "<table class=\"typeSummary\" summary=\"Annotation Types Summary table, listing annotation types, and an explanation\">");

        // Test for package-tree page
        checkOutput("pkg/package-tree.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<li class=\"circle\">");

        // Test for package-use page
        checkOutput("pkg1/package-use.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"useSummary\" summary=\"Use table, listing packages, and an explanation\">");

        // Test for constant-values page
        checkOutput("constant-values.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<table class=\"constantsSummary\" summary=\"Constant Field Values table, listing constant fields, and values\">");

        // Test for deprecated-list page
        checkOutput("deprecated-list.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">\n"
                + "<h1 title=\"Deprecated API\" class=\"title\">Deprecated API</h1>\n"
                + "<h2 title=\"Contents\">Contents</h2>",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Classes table, listing deprecated classes, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Enums table, listing deprecated enums, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Exceptions table, listing deprecated exceptions, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Errors table, listing deprecated errors, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Annotation Types table, listing deprecated annotation types, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Fields table, listing deprecated fields, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Methods table, listing deprecated methods, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Constructors table, listing deprecated constructors, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Enum Constants table, listing deprecated enum constants, and an explanation\">",
                "<table class=\"deprecatedSummary\" summary=\"Deprecated Annotation Type Elements table, listing deprecated annotation type elements, and an explanation\">");

        // Test for serialized-form page
        checkOutput("serialized-form.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<li class=\"blockList\">\n"
                + "<h2 title=\"Package\">Package&nbsp;pkg</h2>");

        // Test for overview-tree page
        checkOutput("overview-tree.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<li class=\"circle\">",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<h1 class=\"title\">Hierarchy For All Packages</h1>\n"
                + "<span class=\"packageHierarchyLabel\">Package Hierarchies:</span>",
                "<div class=\"contentContainer\">\n"
                + "<h2 title=\"Class Hierarchy\">Class Hierarchy</h2>",
                "</ul>\n"
                + "<h2 title=\"Interface Hierarchy\">Interface Hierarchy</h2>",
                "</ul>\n"
                + "<h2 title=\"Enum Hierarchy\">Enum Hierarchy</h2>");

        // Test for index-all page
        checkOutput("index-all.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"contentContainer\">");

        // Test for src-html page
        checkOutput("src-html/pkg/AnotherClass.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<body>\n"
                + "<div class=\"sourceContainer\">");

        // Test for help-doc page
        checkOutput("help-doc.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\">\n"
                + "<h2>Overview</h2>",
                "<li class=\"blockList\">\n"
                + "<h2>Package</h2>",
                "<li class=\"blockList\">\n"
                + "<h2>Class/Interface</h2>");

        // Test for a regular class page and members (nested class, field, constructore and method)
        checkOutput("pkg/AnotherClass.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- ======== NESTED CLASS SUMMARY ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"nested.class.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Nested Class Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Nested Class Summary table, listing nested classes, and an explanation\">",
                "<!-- =========== FIELD SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"field.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Field Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Field Summary table, listing fields, and an explanation\">",
                "<!-- ======== CONSTRUCTOR SUMMARY ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Constructor Summary table, listing constructors, and an explanation\">",
                "<!-- ========== METHOD SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Method Summary table, listing methods, and an explanation\">",
                "<!-- ============ FIELD DETAIL =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"field.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Field Detail</h3>",
                "<!-- ========= CONSTRUCTOR DETAIL ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>",
                "<!-- ============ METHOD DETAIL ========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>");

        // Test for enum page
        checkOutput("pkg/AnotherClass.ModalExclusionType.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- =========== ENUM CONSTANT SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"enum.constant.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Enum Constant Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Enum Constant Summary table, listing enum constants, and an explanation\">",
                "<!-- ========== METHOD SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Method Summary table, listing methods, and an explanation\">",
                "<!-- ============ ENUM CONSTANT DETAIL =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"enum.constant.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Enum Constant Detail</h3>",
                "<!-- ============ METHOD DETAIL ========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>");

        // Test for interface page
        checkOutput("pkg2/Interface.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- ========== METHOD SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Method Summary table, listing methods, and an explanation\">",
                "<!-- ============ METHOD DETAIL ========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>");

        // Test for error page
        checkOutput("pkg/TestError.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- ======== CONSTRUCTOR SUMMARY ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>",
                "<!-- ========= CONSTRUCTOR DETAIL ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>");

        // Test for exception page
        checkOutput("pkg/TestException.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- ======== CONSTRUCTOR SUMMARY ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>",
                "<!-- ========= CONSTRUCTOR DETAIL ======== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>");

        // Test for annotation page
        checkOutput("pkg2/TestAnnotationType.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ======== START OF CLASS DATA ======== -->\n"
                + "<div class=\"header\">",
                "<!-- =========== ANNOTATION TYPE REQUIRED MEMBER SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"annotation.type.required.element.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Required Element Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Required Element Summary table, listing required elements, and an explanation\">",
                "<!-- =========== ANNOTATION TYPE OPTIONAL MEMBER SUMMARY =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"annotation.type.optional.element.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Optional Element Summary</h3>\n"
                + "<table class=\"memberSummary\" summary=\"Optional Element Summary table, listing optional elements, and an explanation\">",
                "<!-- ============ ANNOTATION TYPE MEMBER DETAIL =========== -->\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a name=\"annotation.type.element.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Element Detail</h3>");

        // Test for class use page
        checkOutput("pkg1/class-use/RegClass.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<meta name=\"date\"",
                "<a name=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<!-- ========= END OF TOP NAVBAR ========= -->\n"
                + "</div>\n"
                + "<div class=\"navPadding\">&nbsp;</div>\n"
                + "<div class=\"header\">",
                "<table class=\"useSummary\" summary=\"Use table, listing packages, and an explanation\">",
                "<li class=\"blockList\"><a name=\"pkg\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Uses of <a href=\"../../pkg1/RegClass.html\" title=\"class in pkg1\">RegClass</a> in <a href=\"../../pkg/package-summary.html\">pkg</a></h3>\n"
                + "<table class=\"useSummary\" summary=\"Use table, listing fields, and an explanation\">");

        // Test for main index page
        checkOutput("index.html", true,
                "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">",
                "<link rel=\"stylesheet\" type=\"text/css\" href=\"stylesheet.css\" title=\"Style\">",
                "<body onload=\"loadFrames()\">\n"
                + "<div class=\"mainContainer\">\n"
                + "<div class=\"leftContainer\">\n"
                + "<div class=\"leftTop\">\n"
                + "<iframe src=\"overview-frame.html\" name=\"packageListFrame\" title=\"All Packages\"></iframe>\n"
                + "</div>");
    }

    void html4NegatedOutput() {
        // Negated test for overview-frame page
        checkOutput("overview-frame.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<nav role=\"navigation\" class=\"indexNav\">\n"
                + "<ul>\n"
                + "<li><a href=\"allclasses-frame.html\" target=\"packageFrame\">All&nbsp;Classes</a></li>",
                "<main role=\"main\" class=\"indexContainer\">\n"
                + "<h2 title=\"Packages\">Packages</h2>");

        // Negated test for allclasses-frame page
        checkOutput("allclasses-frame.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<main role=\"main\" class=\"indexContainer\">\n"
                + "<ul>\n"
                + "<li>");

        // Negated test for allclasses-noframe page
        checkOutput("allclasses-noframe.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<main role=\"main\" class=\"indexContainer\">\n"
                + "<ul>\n"
                + "<li>");

        // Negated test for overview-summary page
        checkOutput("overview-summary.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"overviewSummary\">\n"
                + "<caption>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->");

        // Negated test for package-frame page
        checkOutput("pkg/package-frame.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<main role=\"main\">\n"
                + "<h1 class=\"bar\"><a href=\"../pkg/package-summary.html\" target=\"classFrame\">pkg</a></h1>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Interfaces\">Interfaces</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Classes\">Classes</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Enums\">Enums</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Exceptions\">Exceptions</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Errors\">Errors</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Annotation Types\">Annotation Types</h2>");

        // Negated test for package-summary page
        checkOutput("pkg/package-summary.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"typeSummary\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Package pkg Description\">Package pkg Description</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for package-tree page
        checkOutput("pkg/package-tree.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Class Hierarchy\">Class Hierarchy</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Interface Hierarchy\">Interface Hierarchy</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Annotation Type Hierarchy\">Annotation Type Hierarchy</h2>",
                "<section role=\"region\">\n"
                + "<h2 title=\"Enum Hierarchy\">Enum Hierarchy</h2>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for package-use page
        checkOutput("pkg1/package-use.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"useSummary\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for constant-values page
        checkOutput("constant-values.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"constantsSummary\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Contents\">Contents</h2>\n",
                "<section role=\"region\">\n"
                + "<h2 title=\"pkg\">pkg.*</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for deprecated-list page
        checkOutput("deprecated-list.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<table class=\"deprecatedSummary\">",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for serialized-form page
        checkOutput("serialized-form.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Package\">Package&nbsp;pkg</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for overview-tree page
        checkOutput("overview-tree.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2 title=\"Class Hierarchy\">Class Hierarchy</h2>\n",
                "<section role=\"region\">\n"
                + "<h2 title=\"Interface Hierarchy\">Interface Hierarchy</h2>\n",
                "<section role=\"region\">\n"
                + "<h2 title=\"Annotation Type Hierarchy\">Annotation Type Hierarchy</h2>\n",
                "<section role=\"region\">\n"
                + "<h2 title=\"Enum Hierarchy\">Enum Hierarchy</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for index-all page
        checkOutput("index-all.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "</header>\n"
                + "<main role=\"main\">",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for src-html page
        checkOutput("src-html/pkg/AnotherClass.html", false,
                "<!DOCTYPE HTML>",
                "<main role=\"main\">\n"
                + "<div class=\"sourceContainer\">");

        // Negated test for help-doc page
        checkOutput("help-doc.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<h2>Overview</h2>\n",
                "<section role=\"region\">\n"
                + "<h2>Package</h2>\n",
                "<section role=\"region\">\n"
                + "<h2>Class/Interface</h2>\n",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for a regular class page and members (nested class, field, constructore and method)
        checkOutput("pkg/AnotherClass.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"nested.class.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Nested Class Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"field.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Field Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"field.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Field Detail</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for enum page
        checkOutput("pkg/AnotherClass.ModalExclusionType.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"enum.constant.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Enum Constant Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"enum.constant.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Enum Constant Detail</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for interface page
        checkOutput("pkg2/Interface.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"method.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Method Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for error page
        checkOutput("pkg/TestError.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for exception page
        checkOutput("pkg/TestException.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Summary</h3>",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"constructor.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Constructor Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for annotation page
        checkOutput("pkg2/TestAnnotationType.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"annotation.type.required.element.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Required Element Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"annotation.type.optional.element.summary\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Optional Element Summary</h3>\n"
                + "<table class=\"memberSummary\">",
                "<section role=\"region\">\n"
                + "<ul class=\"blockList\">\n"
                + "<li class=\"blockList\"><a id=\"annotation.type.element.detail\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Element Detail</h3>",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for class use page
        checkOutput("pkg1/class-use/RegClass.html", false,
                "<!DOCTYPE HTML>",
                "<meta name=\"dc.created\"",
                "<a id=\"navbar.top.firstrow\">\n"
                + "<!--   -->\n"
                + "</a>",
                "<header role=\"banner\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ========= START OF TOP NAVBAR ======= -->",
                "<main role=\"main\">\n"
                + "<div class=\"header\">",
                "<table class=\"useSummary\">",
                "<section role=\"region\"><a id=\"pkg\">\n"
                + "<!--   -->\n"
                + "</a>\n"
                + "<h3>Uses of <a href=\"../../pkg1/RegClass.html\" title=\"class in pkg1\">RegClass</a> in <a href=\"../../pkg/package-summary.html\">pkg</a></h3>\n"
                + "\n"
                + "<table class=\"useSummary\">",
                "<footer role=\"contentinfo\">\n"
                + "<nav role=\"navigation\">\n"
                + "<!-- ======= START OF BOTTOM NAVBAR ====== -->");

        // Negated test for main index page
        checkOutput("index.html", false,
                "<!DOCTYPE HTML>",
                "<body>\n"
                + "<main role=\"main\">\n"
                + "<div class=\"mainContainer\">\n");
    }
}
